@@ -1,6 +1,3 @@
-##
-##
-
 from __future__ import print_function
 import datetime
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
@@ -8,8 +5,8 @@ from dynamicserialize.dstypes.com.raytheon.uf.common.time import TimeRange
 from awips.dataaccess import DataAccessLayer as DAL
 from awips.ThriftClient import ThriftRequestException
 
-import baseDafTestCase
-import params
+from awips.test.dafTests import baseDafTestCase
+from awips.test.dafTests import params
 import unittest
 
 #
