@@ -1,12 +1,8 @@
-#!/usr/bin/env python
-##
-##
-
 from __future__ import print_function
 from awips.dataaccess import DataAccessLayer as DAL
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
 
-import baseDafTestCase
+from awips.test.dafTests import baseDafTestCase
 import unittest
 
 #
