@@ -5,14 +5,15 @@
 # Adapter for com.raytheon.uf.common.dataplugin.gfe.server.lock.LockTable
 #
 #
-#     SOFTWARE HISTORY
-#
-#    Date            Ticket#       Engineer       Description
-#    ------------    ----------    -----------    --------------------------
-#    04/22/13                      rjpeter       Initial Creation.
-#    06/12/13         #2099        dgilling      Use new Lock constructor.
+# SOFTWARE HISTORY
 #
+# Date          Ticket#  Engineer  Description
+# ------------- -------- --------- ---------------------------------------------
+# Apr 22, 2013           rjpeter   Initial Creation.
+# Jun 12, 2013  2099     dgilling  Use new Lock constructor.
+# Feb 06, 2017  5959     randerso  Removed Java .toString() calls
 #
+##
 
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.server.lock import LockTable
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.server.lock import Lock
@@ -21,12 +22,12 @@ ClassAdapter = 'com.raytheon.uf.common.dataplugin.gfe.server.lock.LockTable'
 
 def serialize(context, lockTable):
     index=0
-    wsIds = {lockTable.getWsId().toString() : index}
+    wsIds = {str(lockTable.getWsId()) : index}
     index += 1
     locks = lockTable.getLocks()
     lockWsIdIndex = []
     for lock in locks:
-        wsIdString = lock.getWsId().toString()
+        wsIdString = str(lock.getWsId())
 
         if wsIdString in wsIds:
             lockWsIdIndex.append(wsIds[wsIdString])
