@@ -17,11 +17,11 @@
 
 
 __all__ = [
-           'records',
-           'Request',
-           'StorageProperties',
-           'StorageStatus',
-           ]
+            'records',
+            'Request',
+            'StorageProperties',
+            'StorageStatus'
+          ]
 
 from .Request import Request
 from .StorageProperties import StorageProperties
